DEGenome – Differential expression across the genome
====================================================
|Build| |Coverage|

DEGenome transforms differential gene expression data to Ideogram_ JSON.

`Read the docs`_, and try the `DEGenome tutorial on Terra
<https://app.terra.bio/#workspaces/degenome/degenome/notebooks/launch/degenome-tutorial.ipynb>`_!

.. |Build| image:: https://img.shields.io/circleci/build/github/eweitz/degenome.svg
  :target: https://circleci.com/gh/eweitz/degenome
.. |Coverage| image:: https://codecov.io/gh/eweitz/degenome/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/eweitz/degenome
.. _Ideogram: https://github.com/eweitz/ideogram
.. _Read the docs: https://degenome.readthedocs.io